@@ -10,7 +10,7 @@
 --
 {-# LANGUAGE ForeignFunctionInterface #-}
 module Crypto.Hash.Blake2s
-    (  Blake2s_256 (..)
+    (  Blake2s_224 (..), Blake2s_256 (..)
     ) where
 
 import           Crypto.Hash.Types
@@ -18,6 +18,18 @@ import           Foreign.Ptr (Ptr)
 import           Data.Word (Word8, Word32)
 
 
+-- | Blake2s (224 bits) cryptographic hash algorithm
+data Blake2s_224 = Blake2s_224
+    deriving (Show)
+
+instance HashAlgorithm Blake2s_224 where
+    hashBlockSize  _          = 64
+    hashDigestSize _          = 28
+    hashInternalContextSize _ = 185
+    hashInternalInit p        = c_blake2s_init p 224
+    hashInternalUpdate        = c_blake2s_update
+    hashInternalFinalize p    = c_blake2s_finalize p 224
+
 -- | Blake2s (256 bits) cryptographic hash algorithm
 data Blake2s_256 = Blake2s_256
     deriving (Show)
