@@ -18,6 +18,7 @@ module Crypto.PubKey.ECC.P256
     , pointBase
     , pointAdd
     , pointMul
+    , pointDh
     , pointsMulVarTime
     , pointIsValid
     , toPoint
@@ -56,7 +57,7 @@ import qualified Crypto.Number.Serialize as S (os2ip, i2ospOf)
 
 -- | A P256 scalar
 newtype Scalar = Scalar ScrubbedBytes
-    deriving (Eq,ByteArrayAccess)
+    deriving (Show,Eq,ByteArrayAccess)
 
 -- | A P256 point
 newtype Point = Point Bytes
@@ -112,6 +113,14 @@ pointMul scalar p = withNewPoint $ \dx dy ->
     withScalar scalar $ \n -> withPoint p $ \px py -> withScalarZero $ \nzero ->
         ccryptonite_p256_points_mul_vartime nzero n px py dx dy
 
+-- | Similar to 'pointMul', serializing the x coordinate as binary
+pointDh :: ByteArray binary => Scalar -> Point -> binary
+pointDh scalar p =
+    B.unsafeCreate scalarSize $ \dst -> withTempPoint $ \dx dy -> do
+        withScalar scalar $ \n -> withPoint p $ \px py -> withScalarZero $ \nzero ->
+            ccryptonite_p256_points_mul_vartime nzero n px py dx dy
+        ccryptonite_p256_to_bin (castPtr dx) dst
+
 -- | multiply the point @p with @n2 and add a lifted to curve value @n1
 --
 -- > n1 * G + n2 * p
@@ -282,6 +291,9 @@ withNewScalarFreeze :: (Ptr P256Scalar -> IO ()) -> Scalar
 withNewScalarFreeze f = Scalar $ B.allocAndFreeze scalarSize f
 {-# NOINLINE withNewScalarFreeze #-}
 
+withTempPoint :: (Ptr P256X -> Ptr P256Y -> IO a) -> IO a
+withTempPoint f = allocTempScrubbed scalarSize (\p -> let px = castPtr p in f px (pxToPy px))
+
 withTempScalar :: (Ptr P256Scalar -> IO a) -> IO a
 withTempScalar f = allocTempScrubbed scalarSize (f . castPtr)
 
